[![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1b66gQ54S5wnjLP9p-wk3X7mMpWHqsA8H?usp=sharing){target="_blank"}

Whether you're a beginner who's never installed Python before or an advanced user who'd like a demo before installing, *Google Colab* is a great way to try all the features of RedPlanet completely in your browser without installing anything! Just open the link above.
